@@ -29,12 +29,16 @@
 
 #include <qof/qof.h>
 
+#include <locale.h>
+#include <monetary.h>
+
 #include "app.h"
 #include "ctree.h"
 #include "cur-proj.h"
 #include "gtt.h"
 #include "ghtml.h"
 #include "ghtml-deprecated.h"
+#include "prefs.h"
 #include "proj.h"
 #include "query.h"
 #include "util.h"
@@ -1090,7 +1094,13 @@ task_get_earliest_str_scm (GttGhtml *ghtml, GttTask *tsk)
 	char buff[100];
 
 	time_t task_date = gtt_task_get_secs_earliest(tsk);
-	size_t len = qof_print_date_time_buff (buff, 100, task_date);
+	size_t len;
+	
+	if (task_date > 0) {
+	    len = qof_print_date_time_buff (buff, 100, task_date);
+	} else {
+        len = g_snprintf(buff, 100, "%s", _("No activity"));
+	}
 	return scm_mem2string (buff, len);
 }
 
@@ -1100,7 +1110,13 @@ task_get_latest_str_scm (GttGhtml *ghtml, GttTask *tsk)
 	char buff[100];
 
 	time_t task_date = gtt_task_get_secs_latest(tsk);
-	size_t len = qof_print_date_time_buff (buff, 100, task_date);
+	size_t len;
+
+	if (task_date > 0) {
+	    len = qof_print_date_time_buff (buff, 100, task_date);
+	} else {
+        len = g_snprintf(buff, 100, "%s", _("No activity"));
+	}
 	return scm_mem2string (buff, len);
 }
 
@@ -1116,6 +1132,7 @@ task_get_value_str_scm (GttGhtml *ghtml, GttTask *tsk)
 	value = ((double) task_secs) / 3600.0;
 
 	prj = gtt_task_get_parent (tsk);
+	
 	switch (gtt_task_get_billrate (tsk))
 	{
 		case GTT_REGULAR: value *= gtt_project_get_billrate (prj); break;
@@ -1124,8 +1141,15 @@ task_get_value_str_scm (GttGhtml *ghtml, GttTask *tsk)
 		case GTT_FLAT_FEE: value = gtt_project_get_flat_fee (prj); break;
 		default: value = 0.0;
 	}
-	/* hack alert should use i18n currency/monetary printing */
-	snprintf (buff, 100, "$%.2f", value+0.0049);
+
+    if (!config_currency_use_locale) {
+      setlocale(LC_MONETARY, "C");
+      setlocale(LC_NUMERIC, "C");
+      snprintf (buff, 100, "%s %.2f", config_currency_symbol, value+0.0049);
+    } else {
+      setlocale(LC_ALL, "");
+      strfmon(buff, 100, "%n", value);
+    }
 
 	return scm_mem2string (buff, strlen (buff));
 }
@@ -1195,7 +1219,22 @@ get_ivl_start_stop_common_str_scm (GttGhtml *ghtml, GttInterval *ivl,
 	if (prt_date) {
 		qof_print_date_buff (buff, 100, starp);
 	} else {
-		qof_print_time_buff (buff, 100, starp);
+        switch (config_time_format) 
+        {
+            case TIME_FORMAT_AM_PM: {
+                strftime (buff, 100, "%r", localtime (&starp));
+                break;
+            }
+            case TIME_FORMAT_24_HS: {
+                strftime (buff, 100, "%T", localtime (&starp));
+                break;
+            }
+            case TIME_FORMAT_LOCALE: {
+                qof_print_time_buff (buff, 100, starp);
+                break;
+            }
+
+        }
 	}
 
 	GString *str;
