@@ -53,6 +53,7 @@
 #include "timer.h"
 #include "toolbar.h"
 #include "xml-gtt.h"
+#include "dbus.h"
 
 char *first_proj_title = NULL;  /* command line over-ride */
 
@@ -293,17 +294,20 @@ resolve_path (const char * pathfrag)
 	return fullpath;
 }
 
-
-static void
-read_data(void)
-{
+void
+read_data(gboolean reloading) {
 	GttErrCode xml_errcode;
 	char * xml_filepath;
 	gboolean read_is_ok;
 	char *errmsg, *qmsg;
 
-	xml_filepath = resolve_old_path (config_data_url);
+  if (reloading) {
+      notes_area_set_project(global_na, NULL);
+      gtt_project_list_destroy(master_list);
+      master_list = gtt_project_list_new();
+  }
 
+	xml_filepath = resolve_old_path (config_data_url);
 	/* Try ... */
 	gtt_err_set_code (GTT_NO_ERR);
 	gtt_xml_read_file (xml_filepath);
@@ -363,10 +367,11 @@ read_data(void)
 	g_free (errmsg);
 }
 
+
 static void
 post_read_config(void)
 {
-	read_data();
+	read_data(FALSE);
 }
 
 static void
@@ -633,7 +638,6 @@ save_projects (void)
 		         G_CALLBACK (gtk_widget_destroy), mb);
 		gtk_widget_show (mb);
 		g_free (errmsg);
-		g_free (errmsg);
 	}
 
 	g_free (xml_filepath);
@@ -781,6 +785,8 @@ main(int argc, char *argv[])
 	g_signal_connect(G_OBJECT(app_window), "delete_event",
 			   G_CALLBACK(app_quit), NULL);
 
+	gnotime_dbus_setup();
+
 	/* Perform QOF-specific initialization. */
 	gnc_engine_get_string_cache();
 	guid_init();
@@ -811,4 +817,5 @@ main(int argc, char *argv[])
 	return 0; /* not reached !? */
 }
 
+
 /* ======================= END OF FILE =================== */
